Clojure only.

clj-libui.callback

Long-lived native callback allocation and retention.

Long-lived native callback allocation and retention.
raw docstring

release-all!clj

(release-all!)

Releases all callback stubs. Call only after native code can no longer use them.

Releases all callback stubs. Call only after native code can no longer use
them.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries