Clojure only.

clj-libui.native

Native libui-ng discovery, extraction, verification, and loading.

Native libui-ng discovery, extraction, verification, and loading.
raw docstring

load!clj

(load!)

Loads libui-ng once and returns a description of the loaded library.

A configured absolute path takes precedence. Otherwise a verified native binary bundled on the classpath is extracted and loaded. The platform library path remains a final development fallback.

Loads libui-ng once and returns a description of the loaded library.

A configured absolute path takes precedence. Otherwise a verified native
binary bundled on the classpath is extracted and loaded. The platform library
path remains a final development fallback.
raw docstring

loaded?clj

(loaded?)

Returns true if this process has successfully loaded libui-ng.

Returns true if this process has successfully loaded libui-ng.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries