clj-libui.queue

One-shot work dispatched through libui-ng's main queue.

One-shot work dispatched through libui-ng's main queue.
raw docstring

enqueue!clj

(enqueue! function)

Queues a no-argument function on libui-ng's main thread.

Returns a CompletableFuture completed with the function's result or error, including rejection while libui-ng is stopped.

Queues a no-argument function on libui-ng's main thread.

Returns a CompletableFuture completed with the function's result or error,
including rejection while libui-ng is stopped.
raw docstring

execute!clj

(execute! function)

Queues a no-argument function with standard Executor rejection semantics.

Queues a no-argument function with standard Executor rejection semantics.
raw docstring

start!clj

(start!)

Allows work to be queued after successful libui-ng initialization.

Allows work to be queued after successful libui-ng initialization.
raw docstring

stop!clj

(stop!)

Fails queued functions which can no longer run because libui-ng is stopping.

Fails queued functions which can no longer run because libui-ng is stopping.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries