clj-libui.runtime

Initialization and thread-affinity rules for libui-ng.

Initialization and thread-affinity rules for libui-ng.
raw docstring

assert-ui-thread!clj

(assert-ui-thread!)

Throws if called outside the thread that initialized libui-ng.

Throws if called outside the thread that initialized libui-ng.
raw docstring

init!clj

(init!)

Loads and initializes libui-ng on the current thread.

Loads and initializes libui-ng on the current thread.
raw docstring

initialized?clj

(initialized?)

Returns true after successful initialization and before uninitialization.

Returns true after successful initialization and before uninitialization.
raw docstring

ui-thread?clj

(ui-thread?)

Returns true when called on the thread that initialized libui-ng.

Returns true when called on the thread that initialized libui-ng.
raw docstring

uninit!clj

(uninit!)

Uninitializes libui-ng. Must run on the initialization thread.

Uninitializes libui-ng. Must run on the initialization thread.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries