Long-lived native callback allocation and retention.
Long-lived native callback allocation and retention.
(release-all!)Releases all callback stubs. Call only after native code can no longer use them.
Releases all callback stubs. Call only after native code can no longer use them.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |