Native libui-ng discovery, extraction, verification, and loading.
Native libui-ng discovery, extraction, verification, and loading.
(load!)Loads libui-ng once and returns a description of the loaded library.
A configured absolute path takes precedence. Otherwise a verified native binary bundled on the classpath is extracted and loaded. The platform library path remains a final development fallback.
Loads libui-ng once and returns a description of the loaded library. A configured absolute path takes precedence. Otherwise a verified native binary bundled on the classpath is extracted and loaded. The platform library path remains a final development fallback.
(loaded?)Returns true if this process has successfully loaded libui-ng.
Returns true if this process has successfully loaded libui-ng.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |