One-shot work dispatched through libui-ng's main queue.
One-shot work dispatched through libui-ng's main queue.
(enqueue! function)Queues a no-argument function on libui-ng's main thread.
Returns a CompletableFuture completed with the function's result or error, including rejection while libui-ng is stopped.
Queues a no-argument function on libui-ng's main thread. Returns a CompletableFuture completed with the function's result or error, including rejection while libui-ng is stopped.
(execute! function)Queues a no-argument function with standard Executor rejection semantics.
Queues a no-argument function with standard Executor rejection semantics.
(start!)Allows work to be queued after successful libui-ng initialization.
Allows work to be queued after successful libui-ng initialization.
(stop!)Fails queued functions which can no longer run because libui-ng is stopping.
Fails queued functions which can no longer run because libui-ng is stopping.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |