Initialization and thread-affinity rules for libui-ng.
Initialization and thread-affinity rules for libui-ng.
(assert-ui-thread!)Throws if called outside the thread that initialized libui-ng.
Throws if called outside the thread that initialized libui-ng.
(init!)Loads and initializes libui-ng on the current thread.
Loads and initializes libui-ng on the current thread.
(initialized?)Returns true after successful initialization and before uninitialization.
Returns true after successful initialization and before uninitialization.
(ui-thread?)Returns true when called on the thread that initialized libui-ng.
Returns true when called on the thread that initialized libui-ng.
(uninit!)Uninitializes libui-ng. Must run on the initialization thread.
Uninitializes libui-ng. Must run on the initialization thread.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |